==> sleepanalyser_1.8-114.tar.gz: sleepanalyser-1.8/src/opt/SleepAnalyser/data.py <==
﻿# -*- coding: utf-8 -*-
###########################################################################
## All global variables in here are used all over the program
###########################################################################

configFolder="/home/user/.SleepAnalyser/" #users home dir with ending /
homedir="/home/user/"
defaultRecordFolder="/home/user/MyDocs/SleepAnalyser/" #users record dir with ending /
ConfigFile="SleepAnalyser.conf"

developmentconfigFolder="/home/gruinelli/Entwicklung/Maemo/GARAGE_SVN/Sleepanalyser/" #development PC
developmentRecordFolder="/home/gruinelli/Entwicklung/Maemo/GARAGE_SVN/Sleepanalyser/data/" #development PC

dateformat="%Y-%m-%d %H:%M:%S" #the date/time is stored in this format in the record files

LogFile="/home/user/MyDocs/SleepAnalyser/SleepAnalyser.log" #Place for log file. IF YOU CHANGE THIS PATH, YOU ALSO HAVE TO CHANGE IT IN /usr/bin/sleepanalyser!


GraphBitMap=""
GraphBitMapLen=0
GraphBitMapHeight=0

StatisticsBitMap=""
StatisticsBitMapLen=110
StatisticsBitMapHeight=65

DisplayIsOn=True
ScrollToEnd=False


#init values
Sampling_interval=1000 #in milliseconds
Sample_index=0
Sample_smoothing=10 #value_smoothing at 1. level
Value_smoothing=10 #value_smoothing at 2. level
Derivation=5 #shift in Derivation

Ysize=121 #default value Y scale in px
Yscale=2 #default value Y stretching
arrXscale=[1, 4, 6] #scaling steps X accis
arrXscaleLen=3
Xscale=1 #default value X scale in arraXscale index

derivation_offset=2

Yscale_sleep=1

Value_index=0
Values_total=0

arrRecordFiles=[]
arrRecordFilesIndex=0

Trigger=14 #Trigger level for movement
maxTrigger=100

demo=0
debug=False

RecordFilename=""
RecordFile=""
RecordFolder=""
LastRecord=""

#ChangesInGraph=False
run=False
QuickMode=False
version="0"
build="0"
configFileVersion=1 #increase if parmeters have changed

user=""
app_path="./"
#passed_time=0
#passed_time2=0
DelayStartTime=10
#DropIndexes=0
last_beep=0
#graphBlocks=0

SwitchedModes=False
OfflineMode=False
PreviousMode="normal"
SilentProfile=False
PreviouseProfile="silent"

language="" #2-letter country code

UIStyle=""

DelayStart=0
interval=0
#GraphStart=0
#GraphStartHours=0
#GraphStartMinutes=0
#AlarmTimeSec=0 #absolute alarm time in seconds
#AlarmDate=0
AlarmHour=-1
AlarmMinute=-1
#AlarmIsSet=False
AlarmIsActive=False
AlarmTimeWindow=30 #in minutes
AlarmID=-1 #cookie for communication to system
#EventSetAlarm=-1
#EventEffectiveAlarm=-1

StopAfterAlarm=True

Status=""
Progress=""

#arrays, indexes, lenghts
#arrDataLen=4680 #(1 value/10sec for 13h), 6*13*60
#arrDataLen=8640 #(1 value/10sec for 24h), 6*24*60
##old             [0]=time            [1]=X,                [2]=Y,                [3]=X Derivation,[4]=Y Derivation
#             [0]=time            [1]=X,                [2]=Y,                [3]=X+Y Derivation, [4]=Time since last movement over treshhold, [5]=event
#arrData=[[0]*arrDataLen, [0]*arrDataLen, [0]*arrDataLen, [0]*arrDataLen,        [0]*arrDataLen ,             [0]*arrDataLen]
arrDataTemp=[0, 0, 0] #[0]=X, [1]=Y, [2]=Z
arrDataIndex=0
arrRecordFiles=[]
arrRecordFilesIndex=0
RecordFileSelectedDate=""

#global QtGui

#Colors
MovementBarColor="#DFAD09" #"Yellow"
#AlarmColor="Red"
#AlarmTimeWindowColor="Orange"
GraphBackground="#000000"
#GraphBackground="#101010"
#some colors are also defined in functions_record.py

noiseReduction=4 #Smoothing of derivation data

FilterScale=40
limitMovement=250


Animation=0

==> sleepanalyser_1.9-1.tar.gz: sleepanalyser-1.9/src/opt/SleepAnalyser/data.py <==
﻿# -*- coding: utf-8 -*-
###########################################################################
## All global variables in here are used all over the program
###########################################################################

configFolder="/home/user/.SleepAnalyser/" #users home dir with ending /
homedir="/home/user/"
defaultRecordFolder="/home/user/MyDocs/SleepAnalyser/" #users record dir with ending /
ConfigFile="SleepAnalyser.conf"

developmentconfigFolder="/home/gruinelli/Entwicklung/Maemo/GARAGE_SVN/Sleepanalyser/" #development PC
developmentRecordFolder="/home/gruinelli/Entwicklung/Maemo/GARAGE_SVN/Sleepanalyser/data/" #development PC

dateformat="%Y-%m-%d %H:%M:%S" #the date/time is stored in this format in the record files

LogFile="/home/user/MyDocs/SleepAnalyser/SleepAnalyser.log" #Place for log file. IF YOU CHANGE THIS PATH, YOU ALSO HAVE TO CHANGE IT IN /usr/bin/sleepanalyser!


GraphBitMap=""
GraphBitMapLen=0
GraphBitMapHeight=0

StatisticsBitMap=""
StatisticsBitMapLen=110
StatisticsBitMapHeight=65

DisplayIsOn=True
ScrollToEnd=False


#init values
Sampling_interval=1000 #in milliseconds
Sample_index=0
Sample_smoothing=10 #value_smoothing at 1. level
Value_smoothing=10 #value_smoothing at 2. level
Derivation=5 #shift in Derivation

Ysize=121 #default value Y scale in px
Yscale=2 #default value Y stretching
arrXscale=[1, 4, 6] #scaling steps X accis
arrXscaleLen=3
Xscale=1 #default value X scale in arraXscale index

derivation_offset=2

Yscale_sleep=1

Value_index=0
Values_total=0

arrRecordFiles=[]
arrRecordFilesIndex=0

Trigger=14 #Trigger level for movement
maxTrigger=120


Light_Sleep_Level=70
Deep_Sleep_Level=30


demo=0
debug=False

RecordFilename=""
RecordFile=""
RecordFolder=""
LastRecord=""

#ChangesInGraph=False
run=False
QuickMode=False
version="0"
build="0"
configFileVersion=2 #increase if parameters have changed

user=""
app_path="./"
#passed_time=0
#passed_time2=0
DelayStartTime=10
#DropIndexes=0
last_beep=0
#graphBlocks=0

SwitchedModes=False
OfflineMode=False
PreviousMode="normal"
SilentProfile=False
PreviouseProfile="silent"

language="" #2-letter country code

UIStyle=""

DelayStart=0
interval=0
#GraphStart=0
#GraphStartHours=0
#GraphStartMinutes=0
#AlarmTimeSec=0 #absolute alarm time in seconds
#AlarmDate=0
AlarmHour=-1
AlarmMinute=-1
#AlarmIsSet=False
AlarmIsActive=False
AlarmTimeWindow=30 #in minutes
AlarmID=-1 #cookie for communication to system
#EventSetAlarm=-1
#EventEffectiveAlarm=-1

StopAfterAlarm=True

Status=""
Progress=""

#arrays, indexes, lenghts
#arrDataLen=4680 #(1 value/10sec for 13h), 6*13*60
#arrDataLen=8640 #(1 value/10sec for 24h), 6*24*60
##old             [0]=time            [1]=X,                [2]=Y,                [3]=X Derivation,[4]=Y Derivation
#             [0]=time            [1]=X,                [2]=Y,                [3]=X+Y Derivation, [4]=Time since last movement over treshhold, [5]=event
#arrData=[[0]*arrDataLen, [0]*arrDataLen, [0]*arrDataLen, [0]*arrDataLen,        [0]*arrDataLen ,             [0]*arrDataLen]
arrDataTemp=[0, 0, 0] #[0]=X, [1]=Y, [2]=Z
arrDataIndex=0
arrRecordFiles=[]
arrRecordFilesIndex=0
RecordFileSelectedDate=""

#global QtGui

#Colors
MovementBarColor="#DFAD09" #"Yellow"
#AlarmColor="Red"
#AlarmTimeWindowColor="Orange"
GraphBackground="#000000"
#GraphBackground="#101010"
GraphBackground2="#2B2B2B"

#Colors for time bars
Deep_Sleep_Color=       "#00C800" #green
Deep_Sleep_ColorDark="#003200"
Light_Sleep_Color=        "#006400" #darker green
Light_Sleep_ColorDark= "#001400"
Awake_Color=                "#860000" #red
Awake_ColorDark=         "#4C0000"





noiseReduction=4 #Smoothing of derivation data

FilterScale=40
limitMovement=250


Animation=0
